==> estateplat-common-1.2.4-20210928.073535-899-sources.jar: cn/gtmap/estateplat/model/server/core/XxgxXtCheckinfo.java <==
package cn.gtmap.estateplat.model.server.core;

import javax.persistence.Id;
import javax.persistence.Table;
import java.util.Date;

/**
 * @author <a href="mailto:zhengqi@gtmap.cn">zhengqi</a>
 * @version 1.0, 2020/11/17
 * @description 省级信息共享-系统验证信息配置表
 */
@Table(name = "xxgx_xt_checkinfo")
public class XxgxXtCheckinfo {
    @Id
    private String id;//主键
    private String sqlxdm;//申请类型
    private String qllxdm;//权利类型
    private String checkCode;//验证类型代码(接口文档中对应的查询类型)
    private String checkModel;//验证模式
    private String checkInfo;//验证信息描述
    private String checkUrl;//验证地址
    private String checkDept;//验证部门
    private String zjlx;//证件类型（同一流程区分不同权利人类型对应的验证项）

    public String getZjlx() {
        return zjlx;
    }

    public void setZjlx(String zjlx) {
        this.zjlx = zjlx;
    }

    public String getId() {
        return id;
    }

    public void setId(String id) {
        this.id = id;
    }

    public String getSqlxdm() {
        return sqlxdm;
    }

    public void setSqlxdm(String sqlxdm) {
        this.sqlxdm = sqlxdm;
    }

    public String getQllxdm() {
        return qllxdm;
    }

    public void setQllxdm(String qllxdm) {
        this.qllxdm = qllxdm;
    }

    public String getCheckModel() {
        return checkModel;
    }

    public void setCheckModel(String checkModel) {
        this.checkModel = checkModel;
    }

    public String getCheckInfo() {
        return checkInfo;
    }

    public void setCheckInfo(String checkInfo) {
        this.checkInfo = checkInfo;
    }

    public String getCheckCode() {
        return checkCode;
    }

    public void setCheckCode(String checkCode) {
        this.checkCode = checkCode;
    }

    public String getCheckUrl() {
        return checkUrl;
    }

    public void setCheckUrl(String checkUrl) {
        this.checkUrl = checkUrl;
    }

    public String getCheckDept() {
        return checkDept;
    }

    public void setCheckDept(String checkDept) {
        this.checkDept = checkDept;
    }
}

==> estateplat-common-1.2.4-20221221.091946-1129-sources.jar: cn/gtmap/estateplat/model/server/core/XxgxXtCheckinfo.java <==
package cn.gtmap.estateplat.model.server.core;

import javax.persistence.Id;
import javax.persistence.Table;
import java.util.Date;

/**
 * @author <a href="mailto:zhengqi@gtmap.cn">zhengqi</a>
 * @version 1.0, 2020/11/17
 * @description 省级信息共享-系统验证信息配置表
 */
@Table(name = "xxgx_xt_checkinfo")
public class XxgxXtCheckinfo {
    @Id
    private String id;//主键
    private String sqlxdm;//申请类型
    private String qllxdm;//权利类型
    private String checkCode;//验证类型代码(接口文档中对应的查询类型)
    private String checkModel;//验证模式
    private String checkInfo;//验证信息描述
    private String checkUrl;//验证地址
    private String checkDept;//验证部门
    private String zjlx;//证件类型（同一流程区分不同权利人类型对应的验证项）
    private String  qlrlx;//权利人类型
    private String cxlx;//查询类型

    public String getZjlx() {
        return zjlx;
    }

    public void setZjlx(String zjlx) {
        this.zjlx = zjlx;
    }

    public String getId() {
        return id;
    }

    public void setId(String id) {
        this.id = id;
    }

    public String getSqlxdm() {
        return sqlxdm;
    }

    public void setSqlxdm(String sqlxdm) {
        this.sqlxdm = sqlxdm;
    }

    public String getQllxdm() {
        return qllxdm;
    }

    public void setQllxdm(String qllxdm) {
        this.qllxdm = qllxdm;
    }

    public String getCheckModel() {
        return checkModel;
    }

    public void setCheckModel(String checkModel) {
        this.checkModel = checkModel;
    }

    public String getCheckInfo() {
        return checkInfo;
    }

    public void setCheckInfo(String checkInfo) {
        this.checkInfo = checkInfo;
    }

    public String getCheckCode() {
        return checkCode;
    }

    public void setCheckCode(String checkCode) {
        this.checkCode = checkCode;
    }

    public String getCheckUrl() {
        return checkUrl;
    }

    public void setCheckUrl(String checkUrl) {
        this.checkUrl = checkUrl;
    }

    public String getCheckDept() {
        return checkDept;
    }

    public void setCheckDept(String checkDept) {
        this.checkDept = checkDept;
    }

    public String getQlrlx() {
        return qlrlx;
    }

    public void setQlrlx(String qlrlx) {
        this.qlrlx = qlrlx;
    }

    public String getCxlx() {
        return cxlx;
    }

    public void setCxlx(String cxlx) {
        this.cxlx = cxlx;
    }
}
